
;+

function sxt_bakeout_in,index,cooling_time=incooling_time

;NAME:
;     SXT_BAKEOUT_IN
;PURPOSE:
;     Determine if an image is during a bakeout
;CATEGORY:
;CALLING SEQUENCE:
;     bake = sxt_bakeout_in(index)
;INPUTS:
;     index = index or time.  Used to get the time of the observation
;OPTIONAL INPUT PARAMETERS:
;KEYWORD PARAMETERS:
;     cooling_time = Time after the end of the bakeout before the CCD
;                    is considered to be cool (hours).  Default = 0.0
;OUTPUTS:
;     bake = byte array, 0 or 1 depending on whether the index time is
;            during a bakeout
;COMMON BLOCKS:
;SIDE EFFECTS:
;RESTRICTIONS:
;PROCEDURE:
;MODIFICATION HISTORY:
;     T. Metcalf 2002-Dec-03
;-

   if n_elements(incooling_time) LE 0 then cooling_time = 0.0 $
   else cooling_time = float(incooling_time)

   bake = get_yo_dates(/bakeout)
   nbake = n_elements(bake)
   bake_times = strarr(nbake,2)
   for i = 0L,nbake-1L do begin
      datearr = splitstr(strcompress(strtrim(bake[i],2)),' ')
      if n_elements(datearr) NE 4 then $
         message,'Error in time format from get_yo_dates(/bakeout)'
      bake_times[i,0] = anytim(anytim(datearr[0]+' '+datearr[1]),/yohkoh)
      bake_times[i,1] = anytim(anytim(datearr[2]+' '+datearr[3]) + $
                               cooling_time*3600.,/yohkoh)
   endfor

   ntimes = n_elements(index)
   inbake = bytarr(ntimes)
   inbake[*] = 0b

   for i=0L,nbake-1L do begin
      inbake = inbake OR sel_timrange(index, bake_times[i,0], bake_times[i,1] , $
                                      /between, /boolean)
   endfor

   return,inbake

end
